import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:get/get.dart';

import 'texts.dart';

class Buttons {
  static Widget defaultButton({
    required VoidCallback handler,
    required Widget widget,
    Color? fillColor,
    bool border = false,
  }) {
    return Padding(
      padding: EdgeInsets.only(top: 10.h),
      child: ElevatedButton(
        onPressed: handler,
        style: ButtonStyle(
          backgroundColor: MaterialStateProperty.all<Color?>(fillColor),
        ),
        child: widget,
      ),
    );
  }

  static Widget textButton({
    required VoidCallback handler,
    required Widget widget,
    EdgeInsets padding = const EdgeInsets.only(top: 10),
    Color? overlayColor,
  }) {
    return Padding(
      padding: padding,
      child: TextButton(
        onPressed: handler,
        style: ButtonStyle(
          overlayColor: MaterialStateProperty.all<Color?>(overlayColor),
        ),
        child: widget,
      ),
    );
  }

  static Widget buttonCard({
    required String title,
    String? subtitle,
    required IconData iconData,
    required VoidCallback handler,
    bool isTrailing = false,
    bool underlined = true,
    Color? textColor,
    required Color iconColor,
  }) {
    return Column(
      children: [
        InkWell(
          onTap: handler,
          child: Container(
            margin: EdgeInsets.all(10.sm),
            padding: EdgeInsets.all(10.sm),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Row(
                  children: [
                    Icon(
                      iconData,
                      color: iconColor,
                    ),
                    SizedBox(
                      width: 20.w,
                    ),
                    Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Texts.body1(
                          title,
                          color: textColor,
                        ),
                        SizedBox(
                          height: 5.h,
                        ),
                        subtitle != null
                            ? Texts.body2(
                                subtitle,
                                color: Colors.grey,
                              )
                            : const SizedBox(),
                      ],
                    ),
                  ],
                ),
                isTrailing
                    ? const Icon(
                        Icons.chevron_right,
                      )
                    : const SizedBox(),
              ],
            ),
          ),
        ),
        underlined
            ? Divider(
                height: 0.h,
                thickness: .5,
              )
            : const SizedBox(),
      ],
    );
  }

  static Widget buttonCard2({
    required String title,
    String? subtitle,
    required IconData iconData,
    required VoidCallback handler,
    bool isTrailing = false,
  }) {
    return Column(
      children: [
        InkWell(
          onTap: handler,
          child: Container(
            margin: EdgeInsets.only(left: 10.w, right: 10.w),
            padding: EdgeInsets.only(top: 10.h, left: 10.w, right: 10.w),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Container(
                  padding: EdgeInsets.all(10.sm),
                  decoration: BoxDecoration(
                    color: Get.theme.primaryColor.withAlpha(50),
                    borderRadius: BorderRadius.circular(15.r),
                  ),
                  child: Icon(
                    iconData,
                    color: Get.theme.primaryColor,
                    size: 35.sm,
                  ),
                ),
                Expanded(
                  child: Column(
                    children: [
                      Padding(
                        padding: EdgeInsets.only(left: 10.w),
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                Texts.body1(title),
                                SizedBox(
                                  height: 5.h,
                                ),
                                subtitle != null
                                    ? Texts.body2(
                                        subtitle,
                                        color: Colors.grey,
                                      )
                                    : const SizedBox(),
                              ],
                            ),
                            isTrailing
                                ? const Icon(
                                    Icons.chevron_right,
                                  )
                                : const SizedBox(),
                          ],
                        ),
                      ),
                      SizedBox(
                        height: 10.h,
                      ),
                      Divider(
                        height: 0.h,
                        thickness: .3.h,
                      ),
                    ],
                  ),
                )
              ],
            ),
          ),
        ),
      ],
    );
  }
}
